<?php

App::uses('AppComponent', 'Controller/Component');

/**
 * Discount code component - listens in all post data to see if a discount code
 * is being applied.
 */
class DiscountCodesComponent extends AppComponent {

	/**
	 * Component startup - check for the form being submitted
	 *
	 * @param Controller $Controller Controller instance
	 * @return bool Returns true if discount applied. A flash status message is also set
	 */
	public function startup(Controller $Controller) {
		if ($this->_controller->request->is('post') && ! empty($this->_controller->request->data['Discount'])) {

			//If the discount is submitted as part of another form then check a code has been supplied
			if (!empty($this->_controller->request->data['Discount']['DiscountCode']['code'])) {
				if (! is_object($this->_controller->BasketManager)) {
					$this->_controller->loadComponent('BasketManager', ['className' => 'EvBasket.Basket']);
				}

				// Check the basket data to see if we already have a discount code applied
				$basketData = $this->_controller->BasketManager->getBasketData();
				$discountCode = Hash::extract($basketData, "{n}[name=discount_code].data");

				if (! empty($discountCode) && Configure::read('EvDiscount.multipleCodes') !== true) {
					$this->_controller->Flash->fail(
						__('A discount code has already been applied'),
						array(
							'key' => 'discount-flash'
						)
					);

					return false;
				}

				$code = $this->_controller->request->data['Discount']['DiscountCode']['code'];
				if (! empty($code)) {

					// Clean up the discount code as it's going to be pretty common
					// for people to copy/paste and accidentaly get a space round it.
					$code = trim($code);

					$DiscountCode = EvClassRegistry::init('EvDiscount.DiscountCode');
					$data = $DiscountCode->getCode($code);

					if (empty($data)) {
						$this->_controller->Flash->fail(
							__('The code entered is not valid'),
							array(
								'key' => 'discount-flash'
							)
						);

						return false;
					}

					// dispatch event
					$this->_controller->getEventManager()->dispatch(
						new CakeEvent('EvDiscount.Component.DiscountCodes.codeAdded', $this, array(
							'code' => $code,
							'data' => $data
						))
					);

					$this->_controller->Flash->success(
						__('Discount code applied'),
						array(
							'key' => 'discount-flash'
						)
					);
				}
			}
		}

		return true;
	}

}
