<?php

App::uses('EvDiscountAppController', 'EvDiscount.Controller');
App::uses('ArrayUtil', 'EvCore.Lib');

class DiscountCodesController extends EvDiscountAppController {

	/**
	 * disable filters
	 */
	protected function _adminFilterFields() {
		$fields = parent::_adminFilterFields();

		$fields['DiscountCode.code'] = array(
			'label' => 'Discount Code',
			'type' => 'string',
			'compare' => array(
				'DiscountCode.code LIKE' => '%%%s%%'
			)
		);

		return $fields;
	}

	/**
	 * Paginator defaults for admin.
	 *
	 * @var array
	 */
	public $adminPaginate = array(
		'contain' => array(
			'Currency'
		)
	);

	/**
	 * add code field to columns
	 */
	protected function _adminIndexColumns() {
		$columns = parent::_adminIndexColumns();

		$columns = ArrayUtil::addAfter(
			$columns,
			'DiscountCode.name',
			array(
				'DiscountCode.code' => array(
					'type' => 'string',
					'label' => __('Code')
				),
				'Currency.name' => array(
					'type' => 'string',
					'label' => __('Currency')
				)
			)
		);

		return $columns;
	}

	/**
	 * populate the lookups
	 */
	protected function _adminPopulateLookups() {
		parent::_adminPopulateLookups();

		$this->set(
			'discountTypes',
			$this->DiscountCode->DiscountType->getForDropdown()
		);
	}

	/**
	 * form fields
	 */
	protected function _adminFormFields() {
		$fields = parent::_adminFormFields();

		$fields['DiscountCode.discount_type_id']['class'] = 'discount-type';
		$fields['DiscountCode.min_order']['label'] = 'Minimum Order Value';

		$fields['DiscountCode.times_used']['info'] = 'This value will automatically increase by one each time the code is used';
		$fields['DiscountCode.maximum_uses']['info'] = 'If this value is set to greater than zero, that will be the maximum number of times this code can be used.';

		return $fields;
	}

	/**
	 * redefine admin_edit
	 */
	public function admin_edit($id = null) {
		$this->toInject('components', 'EvDiscount.CodeRestrictions');
		$this->toInject('components', 'EvCurrency.Currencies');
		$this->toInject('helpers', 'EvDiscount.CodeRestrictions');

		parent::admin_edit($id);

		$this->view = 'EvDiscount.DiscountCodes/admin_form';
	}
}
